@@ -21,7 +21,7 @@ class Account(Base):
 
     def __repr__(self):
         return '<Account {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.name
 
@@ -40,7 +40,7 @@ class Wiki(Base):
 
     def __repr__(self):
         return '<Wiki {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.title
 
@@ -63,7 +63,7 @@ class EnrollmentTerm(Base):
 
     def __repr__(self):
         return '<EnrollmentTerm {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.name
 
@@ -79,7 +79,7 @@ class SisBatch(Base):
 
     def __repr__(self):
         return '<SisBatch {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.id
 
@@ -98,7 +98,7 @@ class Role(Base):
 
     def __repr__(self):
         return '<Role {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.name
 
@@ -168,7 +168,8 @@ class Course(Base):
 
     # Корневая учетная запись
     root_account_id = Column(ForeignKey('accounts.id'))
-    root_account = relationship('Account', foreign_keys='Course.root_account_id')
+    root_account = relationship(
+        'Account', foreign_keys='Course.root_account_id')
 
     enrollment_term_id = Column(ForeignKey('enrollment_terms.id'))
     enrollment_term = relationship('EnrollmentTerm')
@@ -235,10 +236,9 @@ class Course(Base):
 
     grade_passback_setting = Column(String(255))
 
-
     def __repr__(self):
         return '<Course {} (id={}, sis_source_id={})>'.format(self, self.id, self.sis_source_id)
-    
+
     def __str__(self):
         return self.name
 
@@ -303,7 +303,7 @@ class CourseSection(Base):
 
     def __repr__(self):
         return '<CourseSection {} (id={}, sis_source_id={})>'.format(self, self.id, self.sis_source_id)
-    
+
     def __str__(self):
         return self.name
 
@@ -324,7 +324,7 @@ class ContextModule(Base):
 
     def __repr__(self):
         return '<ContextModule {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.name
 
@@ -342,7 +342,7 @@ class ContentTag(Base):
 
     def __repr__(self):
         return '<ContentTag {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.title
 
@@ -364,7 +364,7 @@ class Score(Base):
 
     def __repr__(self):
         return '<Score {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.current_score
 
@@ -388,30 +388,35 @@ class Submission(Base):
 
     def __repr__(self):
         return '<Submission {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return str(self.score)
 
 
 class Assignment(Base):
     """
-    Модель "Задание"
+    Задание
     """
-
     __tablename__ = 'assignments'
 
+    # Идентификатор
     id = Column(Integer, primary_key=True)
+
+    # Наименование
     title = Column(String(255))
 
     # Максимальный балл
     points_possible = Column(Float)
 
+    # LTI-идентификатор
+    lti_context_id = Column(String(255))
+
     submission_types = Column(String(255))
     workflow_state = Column(String(255))
 
     def __repr__(self):
         return '<Assignment {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.title
 
@@ -446,7 +451,7 @@ class Override(Base):
 
     def __repr__(self):
         return '<Override {} (id={} assignment_id={} workflow_state={} quiz_id={})>'.format(self, self.id, self.assignment_id, self.workflow_state, self.quiz_id)
-    
+
     def __str__(self):
         return self.title
 
@@ -462,7 +467,8 @@ class OverrideStudent(Base):
     updated_at = Column(DateTime)
     assignment_id = Column(ForeignKey('assignments.id'))
     assignment = relationship('Assignment')
-    override_id = Column('assignment_override_id', ForeignKey('assignment_overrides.id'))
+    override_id = Column('assignment_override_id',
+                         ForeignKey('assignment_overrides.id'))
     override = relationship('Override')
     user_id = Column(ForeignKey('users.id'))
     user = relationship('User')
@@ -472,7 +478,7 @@ class OverrideStudent(Base):
 
     def __repr__(self):
         return '<OverrideStudent {} (id={} assignment_id={} override_id={} user_id={} quiz_id={} workflow_state={}>'.format(self, self.id, self.assignment_id, self.override_id, self.user_id, self.quiz_id, self.workflow_state)
-    
+
     def __str__(self):
         return str(self.user)
 
@@ -489,7 +495,7 @@ class User(Base):
 
     def __repr__(self):
         return '<User {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.name
 
@@ -509,7 +515,7 @@ class Pseudonym(Base):
 
     def __repr__(self):
         return '<Pseudonym {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return str(self.user)
 
@@ -528,7 +534,7 @@ class Quiz(Base):
 
     def __repr__(self):
         return '<Quiz {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.name
 
@@ -570,7 +576,8 @@ class Enrollment(Base):
     updated_at = Column(DateTime)
 
     associated_user_id = Column(ForeignKey('users.id'))
-    associated_user = relationship('User', foreign_keys='Enrollment.associated_user_id')
+    associated_user = relationship(
+        'User', foreign_keys='Enrollment.associated_user_id')
 
     sis_batch_id = Column(ForeignKey('sis_batches.id'))
     sis_batch = relationship('SisBatch')
@@ -617,7 +624,7 @@ class Enrollment(Base):
 
     def __repr__(self):
         return '<Enrollment {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return str(self.user)
 
@@ -650,6 +657,6 @@ class EnrollmentState(Base):
 
     def __repr__(self):
         return '<EnrollmentState {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
-        return str(self.enrollment)
\ No newline at end of file
+        return str(self.enrollment)
